# arctans

Code for manipulating arctans to generate [Machin-like formulae](https://machin-like.org).

# Installing arctans
## Installing from PyPI using pip
The latest release of arctans can be installed by running:

```bash
pip3 install arctans
```

## Installing from source using pip
arctans can be installed by running:

```bash
pip3 install git+https://github.com/mscroggs/arctans.git
```

# Testing arctans
To run the arctans unit tests, clone the repository and run:

```bash
python3 -m pytest test/
```
